cosmpy.protos.cosmos.gov.v1beta1 package — cosmpy documentation

# cosmpy.protos.cosmos.gov.v1beta1 package

## Submodules

## cosmpy.protos.cosmos.gov.v1beta1.genesis_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.gov.v1beta1.genesis_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.gov.v1beta1.gov_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.gov.v1beta1.gov_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

## cosmpy.protos.cosmos.gov.v1beta1.query_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.gov.v1beta1.query_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.gov.v1beta1.query_pb2_grpc.Query

  Bases: `object`

  Query defines the gRPC querier service for gov module

  static Deposit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Deposits(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Params(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Proposal(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Proposals(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static TallyResult(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Vote(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Votes(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.gov.v1beta1.query_pb2_grpc.QueryServicer

  Bases: `object`

  Query defines the gRPC querier service for gov module

  Deposit(request, context)

    Deposit queries single deposit information based proposalID, depositAddr.

  Deposits(request, context)

    Deposits queries all deposits of a single proposal.

  Params(request, context)

    Params queries all parameters of the gov module.

  Proposal(request, context)

    Proposal queries proposal details based on ProposalID.

  Proposals(request, context)

    Proposals queries all proposals based on given status.

  TallyResult(request, context)

    TallyResult queries the tally of a proposal vote.

  Vote(request, context)

    Vote queries voted information based on proposalID, voterAddr.

  Votes(request, context)

    Votes queries votes of a given proposal.

class cosmpy.protos.cosmos.gov.v1beta1.query_pb2_grpc.QueryStub(channel)

  Bases: `object`

  Query defines the gRPC querier service for gov module

cosmpy.protos.cosmos.gov.v1beta1.query_pb2_grpc.add_QueryServicer_to_server(servicer, server)

## cosmpy.protos.cosmos.gov.v1beta1.tx_pb2 module

Generated protocol buffer code.

## cosmpy.protos.cosmos.gov.v1beta1.tx_pb2_grpc module

Client and server classes corresponding to protobuf-defined services.

class cosmpy.protos.cosmos.gov.v1beta1.tx_pb2_grpc.Msg

  Bases: `object`

  Msg defines the bank Msg service.

  static Deposit(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static SubmitProposal(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)
  static Vote(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None)

class cosmpy.protos.cosmos.gov.v1beta1.tx_pb2_grpc.MsgServicer

  Bases: `object`

  Msg defines the bank Msg service.

  Deposit(request, context)

    Deposit defines a method to add deposit on a specific proposal.

  SubmitProposal(request, context)

    SubmitProposal defines a method to create new proposal given a content.

  Vote(request, context)

    Vote defines a method to add a vote on a specific proposal.

class cosmpy.protos.cosmos.gov.v1beta1.tx_pb2_grpc.MsgStub(channel)

  Bases: `object`

  Msg defines the bank Msg service.

cosmpy.protos.cosmos.gov.v1beta1.tx_pb2_grpc.add_MsgServicer_to_server(servicer, server)

## Module contents